@@ -62,6 +62,7 @@ class QWebChannel;
 class QWebEngineCertificateError;
 class QWebEngineClientCertificateSelection;
 class QWebEngineContextMenuData;
+class QWebEngineFindTextResult;
 class QWebEngineFullScreenRequest;
 class QWebEngineHistory;
 class QWebEnginePage;
@@ -71,13 +72,12 @@ class QWebEngineQuotaRequest;
 class QWebEngineRegisterProtocolHandlerRequest;
 class QWebEngineScriptCollection;
 class QWebEngineSettings;
+class QWebEngineUrlRequestInterceptor;
 
 class QWEBENGINEWIDGETS_EXPORT QWebEnginePage : public QObject {
     Q_OBJECT
     Q_PROPERTY(QString selectedText READ selectedText)
     Q_PROPERTY(bool hasSelection READ hasSelection)
-
-    // Ex-QWebFrame properties
     Q_PROPERTY(QUrl requestedUrl READ requestedUrl)
     Q_PROPERTY(qreal zoomFactor READ zoomFactor WRITE setZoomFactor)
     Q_PROPERTY(QString title READ title)
@@ -89,6 +89,10 @@ class QWEBENGINEWIDGETS_EXPORT QWebEnginePage : public QObject {
     Q_PROPERTY(QPointF scrollPosition READ scrollPosition NOTIFY scrollPositionChanged)
     Q_PROPERTY(bool audioMuted READ isAudioMuted WRITE setAudioMuted NOTIFY audioMutedChanged)
     Q_PROPERTY(bool recentlyAudible READ recentlyAudible NOTIFY recentlyAudibleChanged)
+    Q_PROPERTY(bool visible READ isVisible WRITE setVisible NOTIFY visibleChanged)
+    Q_PROPERTY(LifecycleState lifecycleState READ lifecycleState WRITE setLifecycleState NOTIFY lifecycleStateChanged)
+    Q_PROPERTY(LifecycleState recommendedState READ recommendedState NOTIFY recommendedStateChanged)
+    Q_PROPERTY(qint64 renderProcessPid READ renderProcessPid NOTIFY renderProcessPidChanged)
 
 public:
     enum WebAction {
@@ -181,14 +185,13 @@ public:
         NavigationTypeFormSubmitted,
         NavigationTypeBackForward,
         NavigationTypeReload,
-        NavigationTypeOther
+        NavigationTypeOther,
+        NavigationTypeRedirect,
     };
     Q_ENUM(NavigationType)
 
     enum Feature {
-#ifndef Q_QDOC
         Notifications = 0,
-#endif
         Geolocation = 1,
         MediaAudioCapture = 2,
         MediaVideoCapture,
@@ -224,6 +227,14 @@ public:
     };
     Q_ENUM(RenderProcessTerminationStatus)
 
+    // must match WebContentsAdapterClient::LifecycleState
+    enum class LifecycleState {
+        Active,
+        Frozen,
+        Discarded,
+    };
+    Q_ENUM(LifecycleState)
+
     explicit QWebEnginePage(QObject *parent = Q_NULLPTR);
     QWebEnginePage(QWebEngineProfile *profile, QObject *parent = Q_NULLPTR);
     ~QWebEnginePage();
@@ -244,7 +255,7 @@ public:
 
     void replaceMisspelledWord(const QString &replacement);
 
-    virtual bool event(QEvent*);
+    bool event(QEvent*) override;
 
     void findText(const QString &subString, FindFlags options = FindFlags(), const QWebEngineCallback<bool> &resultCallback = QWebEngineCallback<bool>());
 
@@ -295,6 +306,7 @@ public:
     bool isAudioMuted() const;
     void setAudioMuted(bool muted);
     bool recentlyAudible() const;
+    qint64 renderProcessPid() const;
 
     void printToPdf(const QString &filePath, const QPageLayout &layout = QPageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF()));
     void printToPdf(const QWebEngineCallback<const QByteArray&> &resultCallback, const QPageLayout &layout = QPageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF()));
@@ -305,8 +317,18 @@ public:
     void setDevToolsPage(QWebEnginePage *page);
     QWebEnginePage *devToolsPage() const;
 
+    void setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor *interceptor);
+
     const QWebEngineContextMenuData &contextMenuData() const;
 
+    LifecycleState lifecycleState() const;
+    void setLifecycleState(LifecycleState state);
+
+    LifecycleState recommendedState() const;
+
+    bool isVisible() const;
+    void setVisible(bool visible);
+
 Q_SIGNALS:
     void loadStarted();
     void loadProgress(int progress);
@@ -341,10 +363,18 @@ Q_SIGNALS:
     void contentsSizeChanged(const QSizeF &size);
     void audioMutedChanged(bool muted);
     void recentlyAudibleChanged(bool recentlyAudible);
+    void renderProcessPidChanged(qint64 pid);
 
     void pdfPrintingFinished(const QString &filePath, bool success);
     void printRequested();
 
+    void visibleChanged(bool visible);
+
+    void lifecycleStateChanged(LifecycleState state);
+    void recommendedStateChanged(LifecycleState state);
+
+    void findTextFinished(const QWebEngineFindTextResult &result);
+
 protected:
     virtual QWebEnginePage *createWindow(WebWindowType type);
     virtual QStringList chooseFiles(FileSelectionMode mode, const QStringList &oldFiles, const QStringList &acceptedMimeTypes);
